@@ -5,12 +5,11 @@
 #' @param returns Vector of the returns of the asset or portfolio.
 #' @param evalShape Evaluation of the shape of the IF risk measure if TRUE. Otherwise, a TS of the IF of the provided returns is computed.
 #' @param retVals Values used to evaluate the shape of the IF.
-#' @param nuisPars  Nuisance parameters used for the evaluation of the shape of the IF (if no returns are provided).
+#' @param nuisPars Nuisance parameters used for the evaluation of the shape of the IF (if no returns are provided).
 #' @param k Range parameter for the shape of the IF (the SD gets multiplied k times).
 #' @param IFplot If TRUE, the plot of the IF shape or IF TS of the returns is produced.
 #' @param IFprint If TRUE, the data for the IF shape or the IF TS of the returns is returned.
 #' @param rf Risk-free interest rate.
-#' @param compile Boolean variable to indicate if the IF TS should be computed using compiled code (C++) (TRUE) or not (FALSE).
 #' @param prewhiten Boolean variable to indicate if the IF TS is pre-whitened (TRUE) or not (FALSE).
 #' @param ar.prewhiten.order Order of AR parameter for the pre-whitening. Default is AR(1).
 #' @param cleanOutliers Boolean variable to indicate whether the pre-whitenning of the influence functions TS should be done through a robust filter.
@@ -28,7 +27,7 @@
 #' @examples
 #' # Plot of IF with nuisance parameter with return value
 #' outIF <- IF.SR(returns=NULL, evalShape=TRUE, 
-#'                retVals=NULL, nuisPars =NULL,
+#'                retVals=NULL, nuisPars=NULL,
 #'                IFplot=TRUE, IFprint=TRUE)
 #'
 #' data(edhec, package="PerformanceAnalytics")
@@ -37,19 +36,19 @@
 #' 
 #' # Plot of IF a specified TS 
 #' outIF <- IF.SR(returns=edhec[,"CA"], evalShape=TRUE, 
-#'                retVals=seq(-0.1, 0.1, by=0.001), nuisPars =NULL,
+#'                retVals=seq(-0.1, 0.1, by=0.001), nuisPars=NULL,
 #'                IFplot=TRUE, IFprint=TRUE)
 #' 
 #' # Computing the IF of the returns (with outlier cleaning and prewhitening) with a plot of IF TS
 #' outIF <- IF.SR(returns=edhec[,"CA"], evalShape=FALSE, 
-#'                retVals=NULL, nuisPars =NULL,
+#'                retVals=NULL, nuisPars=NULL,
 #'                IFplot=TRUE, IFprint=TRUE,
-#'                compile=TRUE, prewhiten=FALSE,
+#'                prewhiten=FALSE,
 #'                cleanOutliers=TRUE, cleanMethod=c("locScaleRob", "Boudt")[1], eff=0.99)
 #'
-IF.SR <- function(returns=NULL, evalShape=FALSE, retVals=NULL, nuisPars =NULL, k=4,
+IF.SR <- function(returns=NULL, evalShape=FALSE, retVals=NULL, nuisPars=NULL, k=4,
                   IFplot=FALSE, IFprint=TRUE,
-                  rf=0, compile=TRUE, prewhiten=FALSE, ar.prewhiten.order=1,
+                  rf=0, prewhiten=FALSE, ar.prewhiten.order=1,
                   cleanOutliers=FALSE, cleanMethod=c("locScaleRob", "Boudt")[1], eff=0.99, alpha.robust=0.05,
                   ...){
   
@@ -115,29 +114,29 @@ IF.SR <- function(returns=NULL, evalShape=FALSE, retVals=NULL, nuisPars =NULL, k
   }
   
   # Check data for the nuisance parameters
-  if(!is.null(nuisPars ))
-    if(!is.list(nuisPars ))
+  if(!is.null(nuisPars))
+    if(!is.list(nuisPars))
       stop("nuisPars  must be a list.")
   
   # Evaluation of nuisance parameters
-  if(is.null(nuisPars ))
-    nuisPars  <- nuisParsFn() else{
-      if(!is.null(nuisPars $mu)){
-        nuis.mu <- nuisPars $mu} else{
+  if(is.null(nuisPars))
+    nuisPars <- nuisParsFn() else{
+      if(!is.null(nuisPars$mu)){
+        nuis.mu <- nuisPars$mu} else{
           nuis.mu <- 0.01}
-      if(!is.null(nuisPars $sd)){
-        nuis.sd <- nuisPars $sd} else{
+      if(!is.null(nuisPars$sd)){
+        nuis.sd <- nuisPars$sd} else{
           nuis.sd <- 0.05}
-      if(!is.null(nuisPars $c)){
-        nuis.c <- nuisPars $c} else{
+      if(!is.null(nuisPars$c)){
+        nuis.c <- nuisPars$c} else{
           nuis.c <- 0}
-      if(!is.null(nuisPars $alpha)){
-        nuis.alpha <- nuisPars $alpha} else{
+      if(!is.null(nuisPars$alpha)){
+        nuis.alpha <- nuisPars$alpha} else{
           nuis.alpha <- 0.1}
-      if(!is.null(nuisPars $beta)){
-        nuis.beta <- nuisPars $beta} else{
+      if(!is.null(nuisPars$beta)){
+        nuis.beta <- nuisPars$beta} else{
           nuis.beta <- 0.1}
-      nuisPars  <- nuisParsFn(nuis.mu, nuis.sd, nuis.c, nuis.alpha, nuis.beta)
+      nuisPars <- nuisParsFn(nuis.mu, nuis.sd, nuis.c, nuis.alpha, nuis.beta)
     }
   
   # Function evaluation
@@ -145,7 +144,7 @@ IF.SR <- function(returns=NULL, evalShape=FALSE, retVals=NULL, nuisPars =NULL, k
     if(is.null(retVals))
       if(!is.null(returns))
         retVals <- seq(mean(returns)-k*sd(returns), mean(returns)+k*sd(returns), by=0.001) else
-          retVals <- seq(nuisPars $mu-k*nuisPars $sd, nuisPars $mu+k*nuisPars $sd, by=0.001)
+          retVals <- seq(nuisPars$mu-k*nuisPars$sd, nuisPars$mu+k*nuisPars$sd, by=0.001)
         IFvals <- cbind(retVals, IF.fn(retVals, risk="SR", returns, nuisPars , rf))
         colnames(IFvals) <- c("r", "IFvals")
         if(isTRUE(IFplot)){
@@ -175,17 +174,15 @@ IF.SR <- function(returns=NULL, evalShape=FALSE, retVals=NULL, nuisPars =NULL, k
         returns <- temp.returns
   }
   
-  if(compile){
-    IF.SR.vector <- as.vector(IF_SR(returns, rf))
-  } else{
-    # Computing the mean of the returns
-    mu.hat <- mean(returns)
-    # Computing the SD of the returns
-    sd.hat <- sd(returns)
-    
-    # Computing the IF vector for the SR
-    IF.SR.vector <- 1/sd.hat*(returns-mu.hat)-1/2*mu.hat/sd.hat^3*((returns-mu.hat)^2-sd.hat^2)
-  }
+  # Computing the mean of the returns
+  mu.hat <- mean(returns)
+  # Computing the SD of the returns
+  sd.hat <- sd(returns)
+  # Computing Sharpe Ratio
+  sharpe.hat <- (mu.hat - rf)/sd.hat
+  
+  # Computing the IF vector for the SR
+  IF.SR.vector <- sharpe.hat/2 + (returns - mu.hat)/sd.hat - sharpe.hat/(2*sd.hat^2)*(returns - mu.hat)^2
   
   # Adding the pre-whitening functionality  
   if(prewhiten)
@@ -211,4 +208,9 @@ IF.SR <- function(returns=NULL, evalShape=FALSE, retVals=NULL, nuisPars =NULL, k
   if(xts::is.xts(returns))
     return(xts::xts(IF.SR.vector, returns.dates)) else
       return(IF.SR.vector)
-}
\ No newline at end of file
+}
+
+
+
+
+
